---
author: chainsquad
title: "[uptick.rocks] New python command line tool for BitShares: uptick - brother of piston"
category: chainsquad
tags:
 - bitshares
 - python
 - blockchain
percent_steem_dollars: 0
---

[![](https://bitshares.org/images/transparent_b.png)](http://pybitshares.com)

We are pleased to announce our first public release of [uptick](http://uptick.rocks) in version 0.1.0! This command line tool has been built following the success of [piston](http://piston.rocks).

## What can uptick do, today

* deal with your private keys in a secure and encrypted manner
* modify your account (hierarchical) permissions
* coldstorage/signing
* inspect your account's history
* present any order book and historic trades
* transfer, buy, and sell any asset in the decentralized exchange

## Installation

The source are located on [github/xeroc](https://github.com/xeroc/uptick) but can be installed more conveniently using `pip3`:

    pip3 install uptick   [--user]

## Screenshots

Well, this is a **command line** tool. Don't expect too much fancyness :D

![](https://i.imgsafe.org/5687aa6cab.png)
![](https://i.imgsafe.org/5687b6156a.png)
![](https://i.imgsafe.org/5687c0fd98.png)
![](https://i.imgsafe.org/5687cf24c7.png)
![](https://i.imgsafe.org/5687dc4239.png)

## Funding

This work has been proudly funded by the BitShares blockchain by means of a blockchain worker!

---

## ChainSquad Witness

If you like the services offered by [ChainSquad GmbH](http://chainsquad.com), please consider [approving our new witness](https://steemit.com/steem/@chainsquad/chainsquad-com-for-witness): `chainsquad.com`

Thanks you!
